==> tuxguitar-1.3.0-src.tar.gz: tuxguitar-1.3.0-src/TuxGuitar-android/src/org/herac/tuxguitar/android/view/processing/TGActionProcessingView.java <==
package org.herac.tuxguitar.android.view.processing;

import org.herac.tuxguitar.android.activity.TGActivity;
import org.herac.tuxguitar.util.TGException;
import org.herac.tuxguitar.util.TGSynchronizer;

import android.app.ProgressDialog;

public class TGActionProcessingView {
	
	private TGActivity activity;
	private ProgressDialog dialog;
	
	private boolean visible;
	private boolean updating;
	
	public TGActionProcessingView(TGActivity activity){
		this.activity = activity;
		this.createProgressDialog();
	}
	
	private void createProgressDialog() {
		this.dialog = new ProgressDialog(this.activity);
		this.dialog.setMessage("Processing");
		this.dialog.setIndeterminate(true);
		this.dialog.setCancelable(false);
	}
	
	private void dismissProgressDialog() {
		if(!this.isDestroyed()) {
			this.dialog.dismiss();
			this.dialog = null;
		}
	}
	
	private void updateProgressDialog(boolean visible) {
		if(!this.isDestroyed()) {
			if( visible ) {
				this.dialog.show();
			} else {
				this.dialog.hide();
			}
			this.visible = visible;
		}
	}
	
	public void postUpdateProgressDialog(final boolean visible) {
		if(!this.isDestroyed()) {
			this.updating = true;
			
			TGSynchronizer.getInstance(this.activity.findContext()).executeLater(new Runnable() {
				public void run() throws TGException {
					TGActionProcessingView.this.updateProgressDialog(visible);
					TGActionProcessingView.this.updating = false;
				}
			});
		}
	}

	public void destroy() {
		this.dismissProgressDialog();
	}
	
	public boolean isVisible() {
		return visible;
	}

	public boolean isUpdating() {
		return updating;
	}
	
	public boolean isDestroyed() {
		return (this.dialog == null || this.activity.isDestroyed());
	}
}

==> tuxguitar-1.5.2-src.tar.gz: tuxguitar-1.5.2-src/TuxGuitar-android/src/org/herac/tuxguitar/android/view/processing/TGActionProcessingView.java <==
package org.herac.tuxguitar.android.view.processing;

import android.app.ProgressDialog;

import org.herac.tuxguitar.android.activity.TGActivity;
import org.herac.tuxguitar.util.TGException;
import org.herac.tuxguitar.util.TGSynchronizer;

public class TGActionProcessingView {

	private TGActivity activity;
	private ProgressDialog dialog;

	private boolean updating;
	private boolean destroyed;
	
	public TGActionProcessingView(TGActivity activity){
		this.activity = activity;
	}
	
	private void createProgressDialog() {
		if(!this.isDestroyed() && !this.isVisible()) {
			this.dialog = new ProgressDialog(this.activity);
			this.dialog.setMessage("Processing");
			this.dialog.setIndeterminate(true);
			this.dialog.setCancelable(false);
			this.dialog.show();
		}
	}
	
	private void dismissProgressDialog() {
		if(!this.isDestroyed() && this.isVisible()) {
			this.dialog.dismiss();
			this.dialog = null;
		}
	}
	
	private void updateProgressDialog(boolean visible) {
		if( visible ) {
			this.createProgressDialog();
		} else {
			this.dismissProgressDialog();
		}
	}
	
	public void postUpdateProgressDialog(final boolean visible) {
		if(!this.isDestroyed()) {
			this.updating = true;
			
			TGSynchronizer.getInstance(this.activity.findContext()).executeLater(new Runnable() {
				public void run() throws TGException {
					TGActionProcessingView.this.updateProgressDialog(visible);
					TGActionProcessingView.this.updating = false;
				}
			});
		}
	}

	public void destroy() {
		this.dismissProgressDialog();
		this.destroyed = true;
	}
	
	public boolean isVisible() {
		return (this.dialog != null);
	}

	public boolean isUpdating() {
		return updating;
	}
	
	public boolean isDestroyed() {
		return (this.destroyed || this.activity.isDestroyed());
	}
}
